package
Version:
v1.0.3
Opens a new window with list of versions in this module.
Published: Jun 12, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Content struct {
Schema Schema `json:"schema"`
}
type Info struct {
Title string `json:"title"`
Version string `json:"version"`
}
type Operation struct {
Summary string `json:"summary"`
OperationID string `json:"operationId"`
Tags []string `json:"tags"`
Parameters []Parameter `json:"parameters,omitempty"`
RequestBody *RequestBody `json:"requestBody,omitempty"`
Responses map[string]Response `json:"responses"`
}
type Parameter struct {
Name string `json:"name"`
In string `json:"in"`
Required bool `json:"required,omitempty"`
Description string `json:"description,omitempty"`
Schema Schema `json:"schema"`
}
type RequestBody struct {
Required bool `json:"required,omitempty"`
Content map[string]Content `json:"content"`
}
type Response struct {
Description string `json:"description"`
Content map[string]Content `json:"content,omitempty"`
}
type Schema struct {
Type string `json:"type,omitempty"`
Format string `json:"format,omitempty"`
Properties map[string]Schema `json:"properties,omitempty"`
Items *Schema `json:"items,omitempty"`
Enum []string `json:"enum,omitempty"`
Required []string `json:"required,omitempty"`
}
type Spec struct {
OpenAPI string `json:"openapi"`
Info Info `json:"info"`
Paths map[string]Path `json:"paths"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.